@@ -1,6 +1,5 @@
 from ._osm import *
 import osmium.osm.mutable
-from sys import version_info as python_version
 
 def create_mutable_node(node, **args):
     """ Create a mutable node replacing the properties given in the
@@ -39,10 +38,7 @@ Box.__str__ = lambda b : '(%s %s)' % (b.bottom_left, b.top_right)
 
 Tag.__repr__ = lambda t : 'osmium.osm.Tag(k=%r, v=%r)' % (t.k, t.v)
 
-if python_version >= (3,0):
-    Tag.__str__ = lambda t : '%s=%s' % (t.k, t.v)
-else:
-    Tag.__str__ = lambda t : '%s=%s' % (t.k.encode('utf-8'), t.v.encode('utf-8'))
+Tag.__str__ = lambda t : '%s=%s' % (t.k, t.v)
 
 TagList.__repr__ = lambda t : "osmium.osm.TagList({%s})" \
                               % ",".join(["%r=%r" % (i.k, i.v) for i in t])
