@@ -1,7 +1,6 @@
 """ Helper functions to communicate with replication servers.
 """
 
-import sys
 try:
     import urllib.request as urlrequest
 except ImportError:
@@ -15,6 +14,7 @@ from collections import namedtuple
 from math import ceil
 from osmium import MergeInputReader
 from osmium import io as oio
+from osmium import version
 
 import logging
 
@@ -34,6 +34,10 @@ class ReplicationServer(object):
         self.baseurl = url
         self.diff_type = diff_type
 
+    def make_request(self, url):
+        headers = {"User-Agent" : "pyosmium/{}".format(version.pyosmium_release)}
+        return urlrequest.Request(url, headers=headers)
+
     def open_url(self, url):
         """ Download a resource from the given URL and return a byte sequence
             of the content.
@@ -84,6 +88,7 @@ class ReplicationServer(object):
             try:
                 diffdata = self.get_diff_block(current_id)
             except:
+                log.debug("Error during diff download. Bailing out.")
                 diffdata = ''
             if len(diffdata) == 0:
                 if start_id == current_id:
@@ -132,7 +137,8 @@ class ReplicationServer(object):
         return diffs.id
 
     def apply_diffs_to_file(self, infile, outfile, start_id, max_size=1024,
-                            set_replication_header=True, extra_headers={}):
+                            set_replication_header=True, extra_headers={},
+                            outformat=None):
         """ Download diffs starting with sequence id `start_id`, merge them
             with the data from the OSM file named `infile` and write the result
             into a file with the name `outfile`. The output file must not yet
@@ -150,6 +156,9 @@ class ReplicationServer(object):
             `extra_headers` is a dict with additional header fields to be set.
             Most notably, the 'generator' can be set this way.
 
+            `outformat` sets the format of the output file. If None, the format
+            is determined from the file name.
+
             The function returns a tuple of last downloaded sequence id and
             newest available sequence id if new data has been written or None
             if no data was available or the download failed completely.
@@ -172,7 +181,12 @@ class ReplicationServer(object):
         for k,v in extra_headers.items():
             h.set(k, v)
 
-        writer = oio.Writer(outfile, h)
+        if outformat is None:
+            of = oio.File(outfile)
+        else:
+            of = oio.File(outfile, outformat)
+
+        writer = oio.Writer(of, h)
 
         log.debug("Merging changes into OSM file.")
 
@@ -266,39 +280,47 @@ class ReplicationServer(object):
                 return lower.sequence
 
 
-    def get_state_info(self, seq=None):
+    def get_state_info(self, seq=None, retries=2):
         """ Downloads and returns the state information for the given
             sequence. If the download is successful, a namedtuple with
             `sequence` and `timestamp` is returned, otherwise the function
-            returns `None`.
+            returns `None`. `retries` sets the number of times the download
+            is retried when pyosmium detects a truncated state file.
         """
-        try:
-            response = self.open_url(self.get_state_url(seq))
-        except Exception as err:
-            return None
+        for retry in range(retries + 1):
+            try:
+                response = self.open_url(self.make_request(self.get_state_url(seq)))
+            except Exception as err:
+                log.debug("Loading state info {} failed with: {}".format(seq, str(err)))
+                return None
 
-        ts = None
-        seq = None
-        line = response.readline()
-        while line:
-            line = line.decode('utf-8')
-            if '#' in line:
-                line = line[0:line.index('#')]
-            else:
-                line = line.strip()
-            if line:
-                kv = line.split('=', 2)
-                if len(kv) != 2:
-                    return None
-                if kv[0] == 'sequenceNumber':
-                    seq = int(kv[1])
-                elif kv[0] == 'timestamp':
-                    ts = dt.datetime.strptime(kv[1], "%Y-%m-%dT%H\\:%M\\:%SZ")
-                    if sys.version_info >= (3,0):
-                        ts = ts.replace(tzinfo=dt.timezone.utc)
+            ts = None
+            seq = None
             line = response.readline()
+            while line:
+                line = line.decode('utf-8')
+                if '#' in line:
+                    line = line[0:line.index('#')]
+                else:
+                    line = line.strip()
+                if line:
+                    kv = line.split('=', 2)
+                    if len(kv) != 2:
+                        return None
+                    if kv[0] == 'sequenceNumber':
+                        seq = int(kv[1])
+                    elif kv[0] == 'timestamp':
+                        try:
+                            ts = dt.datetime.strptime(kv[1], "%Y-%m-%dT%H\\:%M\\:%SZ")
+                        except ValueError:
+                            break
+                        ts = ts.replace(tzinfo=dt.timezone.utc)
+                line = response.readline()
 
-        return OsmosisState(sequence=seq, timestamp=ts)
+            if ts is not None and seq is not None:
+                return OsmosisState(sequence=seq, timestamp=ts)
+
+        return None
 
     def get_diff_block(self, seq):
         """ Downloads the diff with the given sequence number and returns
@@ -306,7 +328,7 @@ class ReplicationServer(object):
             (or :code:`urllib2.HTTPError` in python2)
             if the file cannot be downloaded.
         """
-        return self.open_url(self.get_diff_url(seq)).read()
+        return self.open_url(self.make_request(self.get_diff_url(seq))).read()
 
 
     def get_state_url(self, seq):
